==> php54-owncloud-7.0.3.tgz: share/owncloud/apps/calendar/l10n/pl.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nie wszystkie kalendarze są całkowicie buforowane",
"Everything seems to be completely cached" => "Wszystko wydaje się być całkowicie buforowane",
"No calendars found." => "Nie znaleziono kalendarzy.",
"No events found." => "Nie znaleziono wydarzeń.",
"Wrong calendar" => "Nieprawidłowy kalendarz",
"You do not have the permissions to edit this event." => "Nie masz uprawnień, aby edytować to wydarzenie.",
"The file contained either no events or all events are already saved in your calendar." => "Plik nie zawierał żadnych wydarzeń lub wszystkie wydarzenia są już zapisane w kalendarzu.",
"events have been saved in the new calendar" => "zdarzenia zostały zapisane w nowym kalendarzu",
"Import failed" => "Importowanie nieudane",
"events have been saved in your calendar" => "zdarzenie zostało zapisane w twoim kalendarzu",
"New Timezone:" => "Nowa strefa czasowa:",
"Timezone changed" => "Zmieniono strefę czasową",
"Invalid request" => "Nieprawidłowe żądanie",
"Calendar" => "Kalendarz",
"Deletion failed" => "Usunięcie nie powiodło się",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ rrrr]{ - [ddd d] MMMM rrrr}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ rrrr] GG:mm{ - [ ddd d MMMM rrrr] GG:mm}",
"group" => "grupa",
"can edit" => "może edytować",
"can share" => "może współdzielić",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Niedziela",
"Monday" => "Poniedziałek",
"Tuesday" => "Wtorek",
"Wednesday" => "Środa",
"Thursday" => "Czwartek",
"Friday" => "Piątek",
"Saturday" => "Sobota",
"Sun." => "N.",
"Mon." => "Pn.",
"Tue." => "Wt.",
"Wed." => "Śr.",
"Thu." => "Cz.",
"Fri." => "Pt.",
"Sat." => "S.",
"January" => "Styczeń",
"February" => "Luty",
"March" => "Marzec",
"April" => "Kwiecień",
"May" => "Maj",
"June" => "Czerwiec",
"July" => "Lipiec",
"August" => "Sierpień",
"September" => "Wrzesień",
"October" => "Październik",
"November" => "Listopad",
"December" => "Grudzień",
"Jan." => "Sty.",
"Feb." => "Lut.",
"Mar." => "Mar.",
"Apr." => "Kwi.",
"May." => "Maj.",
"Jun." => "Cze.",
"Jul." => "Lip.",
"Aug." => "Sie.",
"Sep." => "Wrz.",
"Oct." => "Paź.",
"Nov." => "Lis.",
"Dec." => "Gru.",
"All day" => "Cały dzień",
"New Calendar" => "Nowy kalendarz",
"Missing or invalid fields" => "Brak lub niewłaściwe pola",
"Title" => "Tytuł",
"From Date" => "Od daty",
"From Time" => "Od czasu",
"To Date" => "Do daty",
"To Time" => "Do czasu",
"The event ends before it starts" => "Wydarzenie kończy się przed rozpoczęciem",
"There was a database fail" => "Awaria bazy danych",
"Interval is not valid. It must be a positive integer!" => "Błędna wartość. Wartość powinna być dodatnią i całkowitą liczbą!",
"Birthday" => "Urodziny",
"Business" => "Biznesowe",
"Call" => "Zadzwoń",
"Clients" => "Klienci",
"Deliverer" => "Dostawca",
"Holidays" => "Święta",
"Ideas" => "Pomysły",
"Journey" => "Podróż",
"Jubilee" => "Jubileusz",
"Meeting" => "Spotkanie",
"Other" => "Inne",
"Personal" => "Osobiste",
"Projects" => "Projekty",
"Questions" => "Pytania",
"Work" => "Zawodowe",
"by" => "przez",
"unnamed" => "nienazwany",
"You do not have the permissions to update this calendar." => "Nie masz uprawnień do aktualizacji tego kalendarza.",
"You do not have the permissions to delete this calendar." => "Nie masz uprawnień, aby usunąć ten kalendarz.",
"You do not have the permissions to add to this calendar." => "Nie masz uprawnień, aby dodawać do tego kalendarza.",
"You do not have the permissions to add events to this calendar." => "Nie masz uprawnień, aby dodać wydarzenia do tego kalendarza.",
"You cannot add non-public events to a shared calendar." => "Nie możesz dodawać niepublicznych zdarzeń do współdzielonego kalendarza.",
"You do not have the permissions to delete this event." => "Nie masz uprawnień, aby usunąć to wydarzenie.",
"Busy" => "Zajęty",
"Show full event" => "Pokaż całe zdarzenie",
"Show only busy" => "Pokaż tylko zajęte",
"Hide event" => "Ukryj zdarzenie",
"Does not repeat" => "Nie powtarza się",
"Daily" => "Codziennie",
"Weekly" => "Cotygodniowo",
"Every Weekday" => "Każdego dnia tygodnia",
"Bi-Weekly" => "Co dwa tygodnie",
"Monthly" => "Comiesięcznie",
"Yearly" => "Corocznie",
"never" => "nigdy",
"by occurrences" => "po wystąpieniach",
"by date" => "po dacie",
"by monthday" => "po dniu miesiąca",
"by weekday" => "po dniu tygodnia",
"events week of month" => "wydarzenia miesiąca",
"first" => "pierwszy",
"second" => "drugi",
"third" => "trzeci",
"fourth" => "czwarty",
"fifth" => "piąty",
"last" => "ostatni",
"by events date" => "po datach wydarzeń",
"by yearday(s)" => "po dniach roku",
"by weeknumber(s)" => "po tygodniach",
"by day and month" => "po dniu i miesiącu",
"Contact birthdays" => "Urodziny",
"Date" => "Data",
"Cal." => "Kal.",
"Day" => "Dzień",
"Week" => "Tydzień",
"Month" => "Miesiąc",
"Today" => "Dziś",
"CalDav Link" => "Odnośnik CalDAV",
"Timezone" => "Strefa czasowa",
"Update timezone automatically" => "Automatyczne aktualizuj strefę czasową",
"Time format" => "Format czasu",
"24h" => "24-godzinny",
"12h" => "12-godzinny",
"Start week on" => "Zaczynaj tydzień od",
"Cache" => "Pamięć podręczna",
"Clear cache for repeating events" => "Wyczyść pamięć podręczną dla powtarzających się zdarzeń",
"Primary CalDAV address" => "Podstawowy adres CalDAV",
"iOS/OS X CalDAV address" => "Adres CalDAV dla iOS/OS X",
"Share Calendar" => "Współdziel kalendarz",
"Download" => "Pobierz",
"Edit" => "Edytuj",
"Delete" => "Usuń",
"New calendar" => "Nowy kalendarz",
"Edit calendar" => "Edytuj kalendarz",
"Edit event" => "Edytuj zdarzenie",
"Save event" => "Zapisz zdarzenie",
"Delete event" => "Usuń zdarzenie",
"Eventinfo" => "Informacja o wydarzeniu",
"Repeating" => "Powtarzające się",
"Alarm" => "Alarm",
"Attendees" => "Uczestnicy",
"Share" => "Udostępnij",
"Title of the Event" => "Nazwa wydarzenia",
"from" => "z",
"to" => "do",
"All Day Event" => "Wydarzenie całodniowe",
"Advanced options" => "Opcje zaawansowane",
"Location" => "Lokalizacja",
"Categories (separate by comma)" => "Kategorie (oddziel przecinkami)",
"Edit categories" => "Edytuj kategorie",
"Description" => "Opis",
"Export event" => "Wyeksportuj zdarzenie",
"Repeat" => "Powtarzaj",
"Advanced" => "Zaawansowane",
"Select weekdays" => "Wybierz dni powszednie",
"Select days" => "Wybierz dni",
"and the events day of year." => "oraz wydarzenia w trakcie roku.",
"and the events day of month." => "oraz wydarzenia w trakcie miesiąca.",
"Select months" => "Wybierz miesiące",
"Select weeks" => "Wybierz tygodnie",
"and the events week of year." => "oraz wydarzenia w trakcie roku.",
"Interval" => "Odstęp",
"End" => "Koniec",
"occurrences" => "wystąpienia",
"Visibility to people shared with" => "Widoczność współdzielona z",
"create a new calendar" => "stwórz nowy kalendarz",
"Import a calendar file" => "Zaimportuj plik kalendarza",
"Please choose a calendar" => "Wybierz kalendarz",
"Name of new calendar" => "Nazwa nowego kalendarza",
"Take an available name!" => "Wybierz dostępną nazwę!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendarz o tej nazwie już istnieje. Jeśli będziesz kontynuować, kalendarze zostaną scalone.",
"Remove all events from the selected calendar" => "Usuń wszystkie wydarzenia z wybranego kalendarza.",
"Import" => "Importuj",
"Close Dialog" => "Zamknij okno",
"Create a new event" => "Utwórz nowe wydarzenie",
"Create event" => "Utwórz zdarzenie",
"Share with user or group" => "Współdziel z użytkownikiem lub grupą",
"Unshare" => "Zatrzymaj współdzielenie",
"Not shared with anyone" => "Nie współdzielony z nikim",
"Send Email" => "Wyślij Email",
"Shared via calendar" => "Udostępnione za pośrednictwem kalendarza",
"Not shared with anyone via calendar" => "Nie współdzielony z nikim przez kalendarz",
"View an event" => "Wyświetl wydarzenie",
"Category" => "Kategoria",
"No categories selected" => "Nie zaznaczono kategorii",
"%s of %s" => "%s z %s",
"Access Class" => "Klasa dostępu",
"From" => "Od",
"at" => "w",
"To" => "Do"
);

==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/calendar/l10n/pl.php <==
<?php
$TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nie wszystkie kalendarze są całkowicie buforowane",
"Everything seems to be completely cached" => "Wszystko wydaje się być całkowicie buforowane",
"No calendars found." => "Nie znaleziono kalendarzy.",
"No events found." => "Nie znaleziono wydarzeń.",
"Wrong calendar" => "Nieprawidłowy kalendarz",
"You do not have the permissions to edit this event." => "Nie masz uprawnień, aby edytować to wydarzenie.",
"The file contained either no events or all events are already saved in your calendar." => "Plik nie zawierał żadnych wydarzeń lub wszystkie wydarzenia są już zapisane w kalendarzu.",
"events have been saved in the new calendar" => "zdarzenia zostały zapisane w nowym kalendarzu",
"Import failed" => "Importowanie nieudane",
"events have been saved in your calendar" => "zdarzenie zostało zapisane w twoim kalendarzu",
"New Timezone:" => "Nowa strefa czasowa:",
"Timezone changed" => "Zmieniono strefę czasową",
"Invalid request" => "Nieprawidłowe żądanie",
"Calendar" => "Kalendarz",
"Error sending mail" => "Błąd podczas wysyłania maila",
"Deletion failed" => "Usunięcie nie powiodło się",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ rrrr]{ - [ddd d] MMMM rrrr}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ rrrr] GG:mm{ - [ ddd d MMMM rrrr] GG:mm}",
"Do you really want to delete this calendar?" => "Czy naprawdę chcesz usunąć ten kalendarz?",
"group" => "grupa",
"can edit" => "może edytować",
"can share" => "może współdzielić",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Niedziela",
"Monday" => "Poniedziałek",
"Tuesday" => "Wtorek",
"Wednesday" => "Środa",
"Thursday" => "Czwartek",
"Friday" => "Piątek",
"Saturday" => "Sobota",
"Sun." => "N.",
"Mon." => "Pn.",
"Tue." => "Wt.",
"Wed." => "Śr.",
"Thu." => "Cz.",
"Fri." => "Pt.",
"Sat." => "S.",
"January" => "Styczeń",
"February" => "Luty",
"March" => "Marzec",
"April" => "Kwiecień",
"May" => "Maj",
"June" => "Czerwiec",
"July" => "Lipiec",
"August" => "Sierpień",
"September" => "Wrzesień",
"October" => "Październik",
"November" => "Listopad",
"December" => "Grudzień",
"Jan." => "Sty.",
"Feb." => "Lut.",
"Mar." => "Mar.",
"Apr." => "Kwi.",
"May." => "Maj.",
"Jun." => "Cze.",
"Jul." => "Lip.",
"Aug." => "Sie.",
"Sep." => "Wrz.",
"Oct." => "Paź.",
"Nov." => "Lis.",
"Dec." => "Gru.",
"All day" => "Cały dzień",
"New Calendar" => "Nowy kalendarz",
"Missing or invalid fields" => "Brak lub niewłaściwe pola",
"Title" => "Tytuł",
"From Date" => "Od daty",
"From Time" => "Od czasu",
"To Date" => "Do daty",
"To Time" => "Do czasu",
"The event ends before it starts" => "Wydarzenie kończy się przed rozpoczęciem",
"There was a database fail" => "Awaria bazy danych",
"Interval is not valid. It must be a positive integer!" => "Błędna wartość. Wartość powinna być dodatnią i całkowitą liczbą!",
"Birthday" => "Urodziny",
"Business" => "Biznesowe",
"Call" => "Zadzwoń",
"Clients" => "Klienci",
"Deliverer" => "Dostawca",
"Holidays" => "Święta",
"Ideas" => "Pomysły",
"Journey" => "Podróż",
"Jubilee" => "Jubileusz",
"Meeting" => "Spotkanie",
"Other" => "Inne",
"Personal" => "Osobiste",
"Projects" => "Projekty",
"Questions" => "Pytania",
"Work" => "Zawodowe",
"by" => "przez",
"unnamed" => "nienazwany",
"You do not have the permissions to update this calendar." => "Nie masz uprawnień do aktualizacji tego kalendarza.",
"You do not have the permissions to delete this calendar." => "Nie masz uprawnień, aby usunąć ten kalendarz.",
"You do not have the permissions to add to this calendar." => "Nie masz uprawnień, aby dodawać do tego kalendarza.",
"You do not have the permissions to add events to this calendar." => "Nie masz uprawnień, aby dodać wydarzenia do tego kalendarza.",
"You cannot add non-public events to a shared calendar." => "Nie możesz dodawać niepublicznych zdarzeń do współdzielonego kalendarza.",
"You do not have the permissions to delete this event." => "Nie masz uprawnień, aby usunąć to wydarzenie.",
"Busy" => "Zajęty",
"Show full event" => "Pokaż całe zdarzenie",
"Show only busy" => "Pokaż tylko zajęte",
"Hide event" => "Ukryj zdarzenie",
"Does not repeat" => "Nie powtarza się",
"Daily" => "Codziennie",
"Weekly" => "Cotygodniowo",
"Every Weekday" => "Każdego dnia tygodnia",
"Bi-Weekly" => "Co dwa tygodnie",
"Monthly" => "Comiesięcznie",
"Yearly" => "Corocznie",
"never" => "nigdy",
"by occurrences" => "po wystąpieniach",
"by date" => "po dacie",
"by monthday" => "po dniu miesiąca",
"by weekday" => "po dniu tygodnia",
"events week of month" => "wydarzenia miesiąca",
"first" => "pierwszy",
"second" => "drugi",
"third" => "trzeci",
"fourth" => "czwarty",
"fifth" => "piąty",
"last" => "ostatni",
"by events date" => "po datach wydarzeń",
"by yearday(s)" => "po dniach roku",
"by weeknumber(s)" => "po tygodniach",
"by day and month" => "po dniu i miesiącu",
"Contact birthdays" => "Urodziny",
"Date" => "Data",
"Day" => "Dzień",
"Week" => "Tydzień",
"Month" => "Miesiąc",
"Today" => "Dziś",
"CalDav Link" => "Odnośnik CalDAV",
"Timezone" => "Strefa czasowa",
"Update timezone automatically" => "Automatyczne aktualizuj strefę czasową",
"Time format" => "Format czasu",
"24h" => "24-godzinny",
"12h" => "12-godzinny",
"Start week on" => "Zaczynaj tydzień od",
"Cache" => "Pamięć podręczna",
"Clear cache for repeating events" => "Wyczyść pamięć podręczną dla powtarzających się zdarzeń",
"Primary CalDAV address" => "Podstawowy adres CalDAV",
"iOS/OS X CalDAV address" => "Adres CalDAV dla iOS/OS X",
"Share Calendar" => "Współdziel kalendarz",
"Download" => "Pobierz",
"Edit" => "Edytuj",
"Delete" => "Usuń",
"New calendar" => "Nowy kalendarz",
"Edit calendar" => "Edytuj kalendarz",
"Edit event" => "Edytuj zdarzenie",
"Save event" => "Zapisz zdarzenie",
"Delete event" => "Usuń zdarzenie",
"Eventinfo" => "Informacja o wydarzeniu",
"Repeating" => "Powtarzające się",
"Alarm" => "Alarm",
"Attendees" => "Uczestnicy",
"Share" => "Udostępnij",
"Title of the Event" => "Nazwa wydarzenia",
"from" => "z",
"to" => "do",
"All Day Event" => "Wydarzenie całodniowe",
"Advanced options" => "Opcje zaawansowane",
"Location" => "Lokalizacja",
"Categories (separate by comma)" => "Kategorie (oddziel przecinkami)",
"Edit categories" => "Edytuj kategorie",
"Description" => "Opis",
"Export event" => "Wyeksportuj zdarzenie",
"Repeat" => "Powtarzaj",
"Advanced" => "Zaawansowane",
"Select weekdays" => "Wybierz dni powszednie",
"Select days" => "Wybierz dni",
"and the events day of year." => "oraz wydarzenia w trakcie roku.",
"and the events day of month." => "oraz wydarzenia w trakcie miesiąca.",
"Select months" => "Wybierz miesiące",
"Select weeks" => "Wybierz tygodnie",
"and the events week of year." => "oraz wydarzenia w trakcie roku.",
"Interval" => "Odstęp",
"End" => "Koniec",
"occurrences" => "wystąpienia",
"Visibility to people shared with" => "Widoczność współdzielona z",
"create a new calendar" => "stwórz nowy kalendarz",
"Import a calendar file" => "Zaimportuj plik kalendarza",
"Please choose a calendar" => "Wybierz kalendarz",
"Name of new calendar" => "Nazwa nowego kalendarza",
"Take an available name!" => "Wybierz dostępną nazwę!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendarz o tej nazwie już istnieje. Jeśli będziesz kontynuować, kalendarze zostaną scalone.",
"Remove all events from the selected calendar" => "Usuń wszystkie wydarzenia z wybranego kalendarza.",
"Import" => "Importuj",
"Close Dialog" => "Zamknij okno",
"Create a new event" => "Utwórz nowe wydarzenie",
"Create event" => "Utwórz zdarzenie",
"Share with user or group" => "Współdziel z użytkownikiem lub grupą",
"Unshare" => "Zatrzymaj współdzielenie",
"Not shared with anyone" => "Nie współdzielony z nikim",
"Send Email" => "Wyślij Email",
"Shared via calendar" => "Udostępnione za pośrednictwem kalendarza",
"Not shared with anyone via calendar" => "Nie współdzielony z nikim przez kalendarz",
"View an event" => "Wyświetl wydarzenie",
"Category" => "Kategoria",
"No categories selected" => "Nie zaznaczono kategorii",
"%s of %s" => "%s z %s",
"Access Class" => "Klasa dostępu",
"From" => "Od",
"at" => "w",
"To" => "Do"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
